@@ -1,3 +1,4 @@
+from typing import Any
 from urllib.parse import quote
 
 from loguru import logger
@@ -17,30 +18,25 @@ class Google(HandOver):
 
     Params Keys
     -----------
-    :param **requests_kwargs: proxies settings
+    :param **request_kwargs: proxies settings
     """
 
-    def __init__(self, **request_kwargs):
+    def __init__(self, **request_kwargs: Any):
         super().__init__(**request_kwargs)
         self.url = "https://www.google.com/searchbyimage"
-        self.params = {}
-        self.header = {
-            "User-Agent": "Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:61.0) Gecko/20100101 Firefox/61.0",
-        }
-        self.requests_kwargs = request_kwargs
 
     @staticmethod
-    def _slice(res: str, index: int = 1) -> GoogleResponse:
+    def _slice(resp: str, index: int = 1) -> GoogleResponse:
         utf8_parser = HTMLParser(encoding="utf-8")
-        d = PyQuery(fromstring(res, parser=utf8_parser))
+        d = PyQuery(fromstring(resp, parser=utf8_parser))
         data = d.find(".g")
         pages = list(d.find("td").items())[1:-1]
         return GoogleResponse(data, pages, index)
 
+    @logger.catch()
     async def goto_page(self, url: str, index: int) -> GoogleResponse:
-        if url:
-            response = await self.get(url, _headers=self.header)
-            return self._slice(response.text, index)
+        resp = await self.get(url)
+        return self._slice(resp.text, index)
 
     @logger.catch()
     async def search(self, url: str) -> GoogleResponse:
@@ -59,14 +55,11 @@ class Google(HandOver):
         • .raw[2].url = First index of url source that was found\n
         • .raw[2].thumbnail = First index of url image that was found
         """
-        params = self.params
         if url[:4] == "http":
             encoded_image_url = quote(url, safe="")
-            params["image_url"] = encoded_image_url
-            response = await self.get(self.url, _params=params, _headers=self.header)
+            params = {"image_url": encoded_image_url}
+            resp = await self.get(self.url, params=params)
         else:
-            multipart = {"encoded_image": (url, open(url, "rb"))}
-            response = await self.post(
-                f"{self.url}/upload", _files=multipart, _headers=self.header
-            )
-        return self._slice(response.text, 1)
+            files = {"encoded_image": (url, open(url, "rb"))}
+            resp = await self.post(f"{self.url}/upload", files=files)
+        return self._slice(resp.text, 1)
