@@ -1,4 +1,4 @@
-from typing import Dict, Union
+from typing import Any, Dict, Optional, Union
 
 from loguru import logger
 
@@ -9,18 +9,17 @@ from .Utils import SauceNAOResponse
 class SauceNAO(HandOver):
     def __init__(
         self,
-        api_key: str = None,
-        *,
+        api_key: Optional[str] = None,
         numres: int = 5,
         hide: int = 1,
         minsim: int = 30,
         output_type: int = 2,
         testmode: int = 0,
-        dbmask: int = None,
-        dbmaski: int = None,
+        dbmask: Optional[int] = None,
+        dbmaski: Optional[int] = None,
         db: int = 999,
-        **requests_kwargs
-    ) -> None:
+        **request_kwargs: Any
+    ):
         """
         SauceNAO
         -----------
@@ -40,9 +39,8 @@ class SauceNAO(HandOver):
         :param hide: (int) result hiding control, none=0, clear return value (default)=1, suspect return value=2, all return value=3
         """
         # minsim 控制最小相似度
-        super().__init__(**requests_kwargs)
+        super().__init__(**request_kwargs)
         self.url = "https://saucenao.com/search.php"
-        self.requests_kwargs = requests_kwargs
         params: Dict[str, Union[str, int]] = {
             "testmode": testmode,
             "numres": numres,
@@ -96,9 +94,9 @@ class SauceNAO(HandOver):
         else:
             # 上传文件
             files = {"file": open(url, "rb")}
-        res = await self.post(
+        resp = await self.post(
             self.url,
-            _params=params,
-            _files=files,
+            params=params,
+            files=files,
         )
-        return SauceNAOResponse(res.json())
+        return SauceNAOResponse(resp.json())
